@@ -1,7 +1,6 @@
-On the local machine
---------------------
+# On the local machine
 
-git checkout v0.7.0
+git checkout v0.16.0  # or whatever
 rm -Rf docs/build/
 cd docs; make html
 cp cheatsheet.pdf /shared/
@@ -10,15 +9,14 @@ touch /shared/python-future-html-docs.zip
 rm /shared/python-future-html-docs.zip
 zip -r /shared/python-future-html-docs.zip *
 
-scp -i ~/.ssh/pythoncharmers_2015.pem /shared/python-future-html-docs.zip python-future.org:
-scp -i ~/.ssh/pythoncharmers_2015.pem /shared/cheatsheet.pdf python-future.org:
+scp /shared/python-future-html-docs.zip python-future.org:
+scp /shared/cheatsheet.pdf python-future.org:
 ssh python-future.org
 
 
-On the remote machine:
-----------------------
+# On the remote machine:
 
-cd /var/www/python-future/
+cd /var/www/python-future.org/
 unzip -o ~/python-future-html-docs.zip
 chmod a+r * html/* html/_static/*
 cp ~/cheatsheet.pdf ./html/compatible_idioms.pdf
