@@ -29,6 +29,20 @@ class TestBytes(unittest.TestCase):
         b = bytes(u, encoding='utf-8')
         self.assertEqual(b, u.encode('utf-8'))
 
+        nu = str(u)
+        b = bytes(nu, encoding='utf-8')
+        self.assertEqual(b, u.encode('utf-8'))
+
+    def test_bytes_encoding_arg_issue_193(self):
+        """
+        This used to be True: bytes(str(u'abc'), 'utf8') == b"b'abc'"
+        """
+        u = u'abc'
+        b = bytes(str(u), 'utf8')
+        self.assertNotEqual(b, b"b'abc'")
+        self.assertEqual(b, b'abc')
+        self.assertEqual(b, bytes(b'abc'))
+
     def test_bytes_encoding_arg_non_kwarg(self):
         """
         As above, but with a positional argument
@@ -37,6 +51,10 @@ class TestBytes(unittest.TestCase):
         b = bytes(u, 'utf-8')
         self.assertEqual(b, u.encode('utf-8'))
 
+        nu = str(u)
+        b = bytes(nu, 'utf-8')
+        self.assertEqual(b, u.encode('utf-8'))
+
     def test_bytes_string_no_encoding(self):
         with self.assertRaises(TypeError):
             bytes(u'ABC')
@@ -290,7 +308,7 @@ class TestBytes(unittest.TestCase):
         exc = str(cm.exception)
         # self.assertIn('bytes', exc)
         # self.assertIn('tuple', exc)
-        
+
     def test_decode(self):
         b = bytes(b'abcd')
         s = b.decode('utf-8')
@@ -357,7 +375,7 @@ class TestBytes(unittest.TestCase):
         d[s] = s
         self.assertEqual(len(d), 2)
         self.assertEqual(set(d.keys()), set([s, b]))
-    
+
     @unittest.expectedFailure
     def test_hash_with_native_types(self):
         # Warning: initializing the dict with native Py2 types throws the
@@ -478,7 +496,7 @@ class TestBytes(unittest.TestCase):
         ValueError
           ...
         ValueError: bytes must be in range(0, 256)
-        
+
         Ensure our bytes() constructor has the same behaviour
         """
         b1 = bytes([254, 255])
@@ -534,105 +552,103 @@ class TestBytes(unittest.TestCase):
         self.assertRaises(ValueError, bytes.maketrans, b'abc', b'xyzq')
         self.assertRaises(TypeError, bytes.maketrans, 'abc', 'def')
 
-    @unittest.expectedFailure
-    def test_mod(self):
-        """
-        From Py3.5 test suite (post-PEP 461).
+    # def test_mod(self):
+    #     """
+    #     From Py3.5 test suite (post-PEP 461).
+    #
+    #     The bytes mod code is in _PyBytes_Format() in bytesobject.c in Py3.5.
+    #     """
+    #     b = b'hello, %b!'
+    #     orig = b
+    #     b = b % b'world'
+    #     self.assertEqual(b, b'hello, world!')
+    #     self.assertEqual(orig, b'hello, %b!')
+    #     self.assertFalse(b is orig)
+    #     b = b'%s / 100 = %d%%'
+    #     a = b % (b'seventy-nine', 79)
+    #     self.assertEqual(a, b'seventy-nine / 100 = 79%')
 
-        The bytes mod code is in _PyBytes_Format() in bytesobject.c in Py3.5.
-        """
-        b = b'hello, %b!'
-        orig = b
-        b = b % b'world'
-        self.assertEqual(b, b'hello, world!')
-        self.assertEqual(orig, b'hello, %b!')
-        self.assertFalse(b is orig)
-        b = b'%s / 100 = %d%%'
-        a = b % (b'seventy-nine', 79)
-        self.assertEqual(a, b'seventy-nine / 100 = 79%')
+    # def test_imod(self):
+    #     """
+    #     From Py3.5 test suite (post-PEP 461)
+    #     """
+    #     # if (3, 0) <= sys.version_info[:2] < (3, 5):
+    #     #     raise unittest.SkipTest('bytes % not yet implemented on Py3.0-3.4')
+    #     b = bytes(b'hello, %b!')
+    #     orig = b
+    #     b %= b'world'
+    #     self.assertEqual(b, b'hello, world!')
+    #     self.assertEqual(orig, b'hello, %b!')
+    #     self.assertFalse(b is orig)
+    #     b = bytes(b'%s / 100 = %d%%')
+    #     b %= (b'seventy-nine', 79)
+    #     self.assertEqual(b, b'seventy-nine / 100 = 79%')
 
-    @unittest.expectedFailure
-    def test_imod(self):
-        """
-        From Py3.5 test suite (post-PEP 461)
-        """
-        # if (3, 0) <= sys.version_info[:2] < (3, 5):
-        #     raise unittest.SkipTest('bytes % not yet implemented on Py3.0-3.4')
-        b = bytes(b'hello, %b!')
-        orig = b
-        b %= b'world'
-        self.assertEqual(b, b'hello, world!')
-        self.assertEqual(orig, b'hello, %b!')
-        self.assertFalse(b is orig)
-        b = bytes(b'%s / 100 = %d%%')
-        b %= (b'seventy-nine', 79)
-        self.assertEqual(b, b'seventy-nine / 100 = 79%')
-
-    @unittest.expectedFailure
-    def test_mod_pep_461(self):
-        """
-        Test for the PEP 461 functionality (resurrection of %s formatting for
-        bytes).
-        """
-        b1 = bytes(b'abc%b')
-        b2 = b1 % b'def'
-        self.assertEqual(b2, b'abcdef')
-        self.assertTrue(isinstance(b2, bytes))
-        self.assertEqual(type(b2), bytes)
-        b3 = b1 % bytes(b'def')
-        self.assertEqual(b3, b'abcdef')
-        self.assertTrue(isinstance(b3, bytes))
-        self.assertEqual(type(b3), bytes)
-
-        # %s is supported for backwards compatibility with Py2's str
-        b4 = bytes(b'abc%s')
-        b5 = b4 % b'def'
-        self.assertEqual(b5, b'abcdef')
-        self.assertTrue(isinstance(b5, bytes))
-        self.assertEqual(type(b5), bytes)
-        b6 = b4 % bytes(b'def')
-        self.assertEqual(b6, b'abcdef')
-        self.assertTrue(isinstance(b6, bytes))
-        self.assertEqual(type(b6), bytes)
-
-        self.assertEqual(bytes(b'%c') % 48, b'0')
-        self.assertEqual(bytes(b'%c') % b'a', b'a')
-
-        # For any numeric code %x, formatting of
-        #     b"%x" % val
-        # is supposed to be equivalent to
-        #     ("%x" % val).encode("ascii")
-        for code in b'xdiouxXeEfFgG':
-            pct_str = u"%" + code.decode('ascii')
-            for val in range(300):
-                self.assertEqual(bytes(b"%" + code) % val,
-                                 (pct_str % val).encode("ascii"))
-
-        with self.assertRaises(TypeError):
-            bytes(b'%b') % 3.14
-            # Traceback (most recent call last):
-            # ...
-            # TypeError: b'%b' does not accept 'float'
-
-        with self.assertRaises(TypeError):
-            bytes(b'%b') % 'hello world!'
-            # Traceback (most recent call last):
-            # ...
-            # TypeError: b'%b' does not accept 'str'
-
-        self.assertEqual(bytes(b'%a') % 3.14, b'3.14')
-
-        self.assertEqual(bytes(b'%a') % b'abc', b"b'abc'")
-        self.assertEqual(bytes(b'%a') % bytes(b'abc'), b"b'abc'")
-
-        self.assertEqual(bytes(b'%a') % 'def', b"'def'")
-
-        # PEP 461 specifes that %r is not supported.
-        with self.assertRaises(TypeError):
-            bytes(b'%r' % b'abc')
-
-        with self.assertRaises(TypeError):
-            bytes(b'%r' % 'abc')
+    # def test_mod_pep_461(self):
+    #     """
+    #     Test for the PEP 461 functionality (resurrection of %s formatting for
+    #     bytes).
+    #     """
+    #     b1 = bytes(b'abc%b')
+    #     b2 = b1 % b'def'
+    #     self.assertEqual(b2, b'abcdef')
+    #     self.assertTrue(isinstance(b2, bytes))
+    #     self.assertEqual(type(b2), bytes)
+    #     b3 = b1 % bytes(b'def')
+    #     self.assertEqual(b3, b'abcdef')
+    #     self.assertTrue(isinstance(b3, bytes))
+    #     self.assertEqual(type(b3), bytes)
+    #
+    #     # %s is supported for backwards compatibility with Py2's str
+    #     b4 = bytes(b'abc%s')
+    #     b5 = b4 % b'def'
+    #     self.assertEqual(b5, b'abcdef')
+    #     self.assertTrue(isinstance(b5, bytes))
+    #     self.assertEqual(type(b5), bytes)
+    #     b6 = b4 % bytes(b'def')
+    #     self.assertEqual(b6, b'abcdef')
+    #     self.assertTrue(isinstance(b6, bytes))
+    #     self.assertEqual(type(b6), bytes)
+    #
+    #     self.assertEqual(bytes(b'%c') % 48, b'0')
+    #     self.assertEqual(bytes(b'%c') % b'a', b'a')
+    #
+    #     # For any numeric code %x, formatting of
+    #     #     b"%x" % val
+    #     # is supposed to be equivalent to
+    #     #     ("%x" % val).encode("ascii")
+    #     for code in b'xdiouxXeEfFgG':
+    #         bytechar = bytes([code])
+    #         pct_str = u"%" + bytechar.decode('ascii')
+    #         for val in range(300):
+    #             self.assertEqual(bytes(b"%" + bytechar) % val,
+    #                              (pct_str % val).encode("ascii"))
+    #
+    #     with self.assertRaises(TypeError):
+    #         bytes(b'%b') % 3.14
+    #         # Traceback (most recent call last):
+    #         # ...
+    #         # TypeError: b'%b' does not accept 'float'
+    #
+    #     with self.assertRaises(TypeError):
+    #         bytes(b'%b') % 'hello world!'
+    #         # Traceback (most recent call last):
+    #         # ...
+    #         # TypeError: b'%b' does not accept 'str'
+    #
+    #     self.assertEqual(bytes(b'%a') % 3.14, b'3.14')
+    #
+    #     self.assertEqual(bytes(b'%a') % b'abc', b"b'abc'")
+    #     self.assertEqual(bytes(b'%a') % bytes(b'abc'), b"b'abc'")
+    #
+    #     self.assertEqual(bytes(b'%a') % 'def', b"'def'")
+    #
+    #     # PEP 461 was updated after an Py3.5 alpha release to specify that %r is now supported
+    #     # for compatibility: http://legacy.python.org/dev/peps/pep-0461/#id16
+    #     assert bytes(b'%r' % b'abc') == bytes(b'%a' % b'abc')
+    #
+    #     # with self.assertRaises(TypeError):
+    #     #     bytes(b'%r' % 'abc')
 
     @expectedFailurePY2
     def test_multiple_inheritance(self):
@@ -674,6 +690,23 @@ class TestBytes(unittest.TestCase):
             self.assertTrue(isinstance(decoded, str))
             self.assertEqual(b, decoded.encode('utf-8', 'surrogateescape'))
 
+    def test_issue_171_part_a(self):
+        b1 = str(u'abc \u0123 do re mi').encode(u'utf_8')
+        b2 = bytes(u'abc \u0123 do re mi', u'utf_8')
+        b3 = bytes(str(u'abc \u0123 do re mi'), u'utf_8')
+
+    @expectedFailurePY2
+    def test_issue_171_part_b(self):
+        """
+        Tests whether:
+        >>> nativebytes = bytes ; nativestr = str ; from builtins import *
+        >>> nativebytes(bytes(b'asdf'))[0] == b'a' == b'asdf'
+        """
+        nativebytes = type(b'')
+        nativestr = type('')
+        b = nativebytes(bytes(b'asdf'))
+        self.assertEqual(b, b'asdf')
+
 
 if __name__ == '__main__':
     unittest.main()
